==> vmaid-1.8.5.tar.gz: vmaid-1.8.5/src/size.c <==
/*
    Video maid
    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include <gdk/gdkkeysyms.h>
#include "size.h"


/******************************************************************************
*                                                                             *
* ѹؿ                                                            *
*                                                                             *
******************************************************************************/
/*	ե졼ॵ
	      view,
	     width,
	    height,⤵
	 def_width,ǥեȤ
	def_height,ǥեȤι⤵												*/
void size_set_scale(const gint view,gint *width,gint *height,
									const gint def_width,const gint def_height)
{
	switch (def_width<=0 || def_height<=0?view|4:view) {
		case 0:*width=def_width;  *height=def_height;break;
		case 1:*width=def_width/2;*height=def_height/2;break;
		case 2:*width=def_width/4;*height=def_height/4;break;
		case 3:*width=def_width/8;*height=def_height/8;break;
		case 4:*width=320;        *height=240;return;
		case 5:*width=160;        *height=120;return;
		case 6:*width=80;         *height=60;return;
		case 7:*width=40;         *height=30;return;
	}
	if (*width<1)
		*width=1;
	if (*height<1)
		*height=1;
}


/******************************************************************************
*                                                                             *
* ѹؿ                                                  *
*                                                                             *
******************************************************************************/
static gboolean edit,size_clicked_ok;
static gint def_view;
static GtkWidget *dialog,*button8,*check,*spin0,*spin1;


/* ԥܥͤѲ */
static void size_dialog_changed(GtkWidget *widget,SizeDialog *size)
{
	gint width,height;

	if (edit) {
		edit=FALSE;
		width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
		height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
		if (size->def_width>0 && size->def_height>0
				&& !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check))) {
			/* /Ψݻ */
			if (widget==spin0) {
				height=MAX(width*size->def_height/size->def_width,1);
				gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),height);
			} else {
				width=MAX(height*size->def_width/size->def_height,1);
				gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),width);
			}
		}
		gtk_widget_set_sensitive(button8,0<width && 0<height);
		edit=TRUE;
	}
}


/* OKܥ󤬲줿 */
static void size_dialog_clicked_ok(GtkWidget *widget,SizeDialog *size)
{
	if (def_view>0)
		size->view=def_view;
	if (size->def_width>0 && size->def_height>0)
		size->ratio=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
	size->width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	size->height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	gtk_widget_destroy(dialog);
	size_clicked_ok=TRUE;
}


/* ܥ󤬲줿 */
static void size_dialog_clicked_button(GtkWidget *widget,SizeDialog *size)
{
	gint width,height;

	def_view=(gint)gtk_object_get_user_data(GTK_OBJECT(widget));
	size_set_scale(def_view,&width,&height,size->def_width,size->def_height);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),width);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),height);
}


/* ԥܥǥ꥿󤬲줿 */
static void size_dialog_activate(GtkWidget *widget,SizeDialog *size)
{
	gint width,height;

	width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	if (0<width && 0<height)
		size_dialog_clicked_ok(widget,size);
}


/* ESC줿 */
static gboolean size_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
															gpointer user_data)
{
	if (event->keyval==GDK_Escape)
		gtk_widget_destroy(widget);
	return FALSE;
}


gboolean size_dialog(SizeDialog *size)
{
	guint key;
	GtkAccelGroup *accel;
	GtkWidget *button0,*button1,*button2,*button3;
	GtkWidget *button4,*button5,*button6,*button7,*button9;
	GtkWidget *label0,*label1,*table,*hbox0,*hbox1,*vbox;

	/* ᥤ󥦥ɥ */
	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
	gtk_window_set_title(GTK_WINDOW(dialog),_("Size"));
	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
								GTK_SIGNAL_FUNC(size_dialog_key_press),NULL);
	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
	/* 졼 */
	accel=gtk_accel_group_new();
	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
	/* ܥ */
	if (size->def_width>0 && size->def_height>0) {
		button0=gtk_button_new_with_label(_("Standard"));
		button1=gtk_button_new_with_label(_("1/2"));
		button2=gtk_button_new_with_label(_("1/4"));
		button3=gtk_button_new_with_label(_("1/8"));
		gtk_object_set_user_data(GTK_OBJECT(button0),(gpointer)0);
		gtk_object_set_user_data(GTK_OBJECT(button1),(gpointer)1);
		gtk_object_set_user_data(GTK_OBJECT(button2),(gpointer)2);
		gtk_object_set_user_data(GTK_OBJECT(button3),(gpointer)3);
		gtk_signal_connect(GTK_OBJECT(button0),"clicked",
											size_dialog_clicked_button,size);
		gtk_signal_connect(GTK_OBJECT(button1),"clicked",
											size_dialog_clicked_button,size);
		gtk_signal_connect(GTK_OBJECT(button2),"clicked",
											size_dialog_clicked_button,size);
		gtk_signal_connect(GTK_OBJECT(button3),"clicked",
											size_dialog_clicked_button,size);
		GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
		GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
		GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
		GTK_WIDGET_SET_FLAGS(button3,GTK_CAN_DEFAULT);
	} else {
		button0=button1=button2=button3=NULL;
	}
	button4=gtk_button_new_with_label(_("320\xd7240"));
	button5=gtk_button_new_with_label(_("160\xd7120"));
	button6=gtk_button_new_with_label(_("80\xd760"));
	button7=gtk_button_new_with_label(_("40\xd730"));
	button8=gtk_button_new_with_label(_("OK"));
	button9=gtk_button_new_with_label(_("Cancel"));
	gtk_object_set_user_data(GTK_OBJECT(button4),(gpointer)4);
	gtk_object_set_user_data(GTK_OBJECT(button5),(gpointer)5);
	gtk_object_set_user_data(GTK_OBJECT(button6),(gpointer)6);
	gtk_object_set_user_data(GTK_OBJECT(button7),(gpointer)7);
	gtk_signal_connect(GTK_OBJECT(button4),"clicked",
											size_dialog_clicked_button,size);
	gtk_signal_connect(GTK_OBJECT(button5),"clicked",
											size_dialog_clicked_button,size);
	gtk_signal_connect(GTK_OBJECT(button6),"clicked",
											size_dialog_clicked_button,size);
	gtk_signal_connect(GTK_OBJECT(button7),"clicked",
											size_dialog_clicked_button,size);
	gtk_signal_connect(GTK_OBJECT(button8),"clicked",
												size_dialog_clicked_ok,size);
	gtk_signal_connect_object(GTK_OBJECT(button9),"clicked",
										gtk_widget_destroy,GTK_OBJECT(dialog));
	GTK_WIDGET_SET_FLAGS(button4,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button5,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button6,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button7,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button8,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button9,GTK_CAN_DEFAULT);
	/* åܥ */
	if (size->def_width>0 && size->def_height>0) {
		check=gtk_check_button_new_with_label(NULL);
		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
													_("_Allow distortion"));
		gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),size->ratio);
	} else {
		check=NULL;
	}
	/* ԥܥ */
	spin0=gtk_spin_button_new(
		GTK_ADJUSTMENT(gtk_adjustment_new(size->width,1,G_MAXINT,1,5,0)),0,0);
	spin1=gtk_spin_button_new(
		GTK_ADJUSTMENT(gtk_adjustment_new(size->height,1,G_MAXINT,1,5,0)),0,0);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin0),TRUE);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin1),TRUE);
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin0),GTK_SHADOW_IN);
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin1),GTK_SHADOW_IN);
	gtk_signal_connect(GTK_OBJECT(spin0),"activate",size_dialog_activate,size);
	gtk_signal_connect(GTK_OBJECT(spin1),"activate",size_dialog_activate,size);
	gtk_signal_connect(GTK_OBJECT(spin0),"changed",size_dialog_changed,size);
	gtk_signal_connect(GTK_OBJECT(spin1),"changed",size_dialog_changed,size);
	/* ٥ */
	label0=gtk_label_new(NULL);
	label1=gtk_label_new(NULL);
	key=gtk_label_parse_uline(GTK_LABEL(label0),_("_Width"));
	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(label1),_("_Height"));
	gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	/* ơ֥ */
	if (button0!=NULL && button1!=NULL && button2!=NULL && button3!=NULL) {
		table=gtk_table_new(2,4,FALSE);
		gtk_table_attach_defaults(GTK_TABLE(table),button0,0,1,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button1,1,2,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button2,2,3,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button3,3,4,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button4,0,1,1,2);
		gtk_table_attach_defaults(GTK_TABLE(table),button5,1,2,1,2);
		gtk_table_attach_defaults(GTK_TABLE(table),button6,2,3,1,2);
		gtk_table_attach_defaults(GTK_TABLE(table),button7,3,4,1,2);
	} else {
		table=gtk_table_new(1,4,FALSE);
		gtk_table_attach_defaults(GTK_TABLE(table),button4,0,1,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button5,1,2,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button6,2,3,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button7,3,4,0,1);
	}

	/* ե졼ȥܥå */
	vbox=gtk_vbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
	gtk_box_pack_start(GTK_BOX(vbox),table,FALSE,FALSE,0);

	hbox0=gtk_hbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(hbox0),8);
	hbox1=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),label0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),spin0,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
	hbox1=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),label1,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),spin1,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);

	if (check!=NULL)
		gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);

	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_end(GTK_BOX(hbox0),button9,FALSE,FALSE,0);
	gtk_box_pack_end(GTK_BOX(hbox0),button8,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	gtk_container_add(GTK_CONTAINER(dialog),vbox);

	/* ɽ */
	gtk_widget_set_sensitive(button8,FALSE);
	gtk_widget_grab_focus(button9);

	edit=TRUE;
	def_view=-1;
	size_clicked_ok=FALSE;

	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
	gtk_grab_add(dialog);
	gtk_widget_show_all(dialog);
	gtk_main();

	return size_clicked_ok;
}

==> vmaid-1.8.11.tar.gz: vmaid-1.8.11/src/size.c <==
/*
    Video maid
    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "size.h"
#include <gdk/gdkkeysyms.h>


/******************************************************************************
*                                                                             *
* ѹؿ                                                            *
*                                                                             *
******************************************************************************/
/*	ե졼ॵ
	      view,
	     width,
	    height,⤵
	 def_width,ǥեȤ
	def_height,ǥեȤι⤵												*/
void size_set_scale(const gint view,gint *width,gint *height,
									const gint def_width,const gint def_height)
{
	switch (def_width<=0 || def_height<=0?view|4:view) {
		case 0:*width=def_width;  *height=def_height;break;
		case 1:*width=def_width/2;*height=def_height/2;break;
		case 2:*width=def_width/4;*height=def_height/4;break;
		case 3:*width=def_width/8;*height=def_height/8;break;
		case 4:*width=320;        *height=240;return;
		case 5:*width=160;        *height=120;return;
		case 6:*width=80;         *height=60;return;
		case 7:*width=40;         *height=30;return;
	}
	if (*width<1)
		*width=1;
	if (*height<1)
		*height=1;
}


/******************************************************************************
*                                                                             *
* ѹؿ                                                  *
*                                                                             *
******************************************************************************/
static gboolean edit,size_clicked_ok;
static gint def_view;
static GtkWidget *dialog,*button8,*check,*spin0,*spin1;


/* ԥܥͤѲ */
static void size_dialog_changed(GtkWidget *widget,SizeDialog *size)
{
	gint width,height;

	if (edit) {
		edit=FALSE;
		width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
		height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
		if (size->def_width>0 && size->def_height>0
				&& !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check))) {
			/* /Ψݻ */
			if (widget==spin0) {
				height=MAX(width*size->def_height/size->def_width,1);
				gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),height);
			} else {
				width=MAX(height*size->def_width/size->def_height,1);
				gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),width);
			}
		}
		gtk_widget_set_sensitive(button8,0<width && 0<height);
		edit=TRUE;
	}
}


/* OKܥ󤬲줿 */
static void size_dialog_clicked_ok(GtkWidget *widget,SizeDialog *size)
{
	if (def_view>0)
		size->view=def_view;
	if (size->def_width>0 && size->def_height>0)
		size->ratio=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check));
	size->width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	size->height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	gtk_widget_destroy(dialog);
	size_clicked_ok=TRUE;
}


/* ܥ󤬲줿 */
static void size_dialog_clicked_button(GtkWidget *widget,SizeDialog *size)
{
	gint width,height;

	def_view=(gint)gtk_object_get_user_data(GTK_OBJECT(widget));
	size_set_scale(def_view,&width,&height,size->def_width,size->def_height);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),width);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),height);
}


/* ԥܥǥ꥿󤬲줿 */
static void size_dialog_activate(GtkWidget *widget,SizeDialog *size)
{
	gint width,height;

	width=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
	height=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
	if (0<width && 0<height)
		size_dialog_clicked_ok(widget,size);
}


/* ESC줿 */
static gboolean size_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
															gpointer user_data)
{
	if (event->keyval==GDK_Escape)
		gtk_widget_destroy(widget);
	return FALSE;
}


gboolean size_dialog(SizeDialog *size)
{
	guint key;
	GtkAccelGroup *accel;
	GtkWidget *button0,*button1,*button2,*button3;
	GtkWidget *button4,*button5,*button6,*button7,*button9;
	GtkWidget *label0,*label1,*table,*hbox0,*hbox1,*vbox;

	/* ᥤ󥦥ɥ */
	dialog=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(dialog),_("Size"));
	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
								GTK_SIGNAL_FUNC(size_dialog_key_press),NULL);
	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
	/* 졼 */
	accel=gtk_accel_group_new();
	gtk_window_add_accel_group(GTK_WINDOW(dialog),accel);
	/* ܥ */
	if (size->def_width>0 && size->def_height>0) {
		button0=gtk_button_new_with_label(_("Standard"));
		button1=gtk_button_new_with_label(_("1/2"));
		button2=gtk_button_new_with_label(_("1/4"));
		button3=gtk_button_new_with_label(_("1/8"));
		gtk_object_set_user_data(GTK_OBJECT(button0),(gpointer)0);
		gtk_object_set_user_data(GTK_OBJECT(button1),(gpointer)1);
		gtk_object_set_user_data(GTK_OBJECT(button2),(gpointer)2);
		gtk_object_set_user_data(GTK_OBJECT(button3),(gpointer)3);
		gtk_signal_connect(GTK_OBJECT(button0),"clicked",
							GTK_SIGNAL_FUNC(size_dialog_clicked_button),size);
		gtk_signal_connect(GTK_OBJECT(button1),"clicked",
							GTK_SIGNAL_FUNC(size_dialog_clicked_button),size);
		gtk_signal_connect(GTK_OBJECT(button2),"clicked",
							GTK_SIGNAL_FUNC(size_dialog_clicked_button),size);
		gtk_signal_connect(GTK_OBJECT(button3),"clicked",
							GTK_SIGNAL_FUNC(size_dialog_clicked_button),size);
		GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
		GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
		GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
		GTK_WIDGET_SET_FLAGS(button3,GTK_CAN_DEFAULT);
	} else {
		button0=button1=button2=button3=NULL;
	}
	button4=gtk_button_new_with_label(_("320x240"));
	button5=gtk_button_new_with_label(_("160x120"));
	button6=gtk_button_new_with_label(_("80x60"));
	button7=gtk_button_new_with_label(_("40x30"));
	button8=gtk_button_new_with_label(_("OK"));
	button9=gtk_button_new_with_label(_("Cancel"));
	gtk_object_set_user_data(GTK_OBJECT(button4),(gpointer)4);
	gtk_object_set_user_data(GTK_OBJECT(button5),(gpointer)5);
	gtk_object_set_user_data(GTK_OBJECT(button6),(gpointer)6);
	gtk_object_set_user_data(GTK_OBJECT(button7),(gpointer)7);
	gtk_signal_connect(GTK_OBJECT(button4),"clicked",
							GTK_SIGNAL_FUNC(size_dialog_clicked_button),size);
	gtk_signal_connect(GTK_OBJECT(button5),"clicked",
							GTK_SIGNAL_FUNC(size_dialog_clicked_button),size);
	gtk_signal_connect(GTK_OBJECT(button6),"clicked",
							GTK_SIGNAL_FUNC(size_dialog_clicked_button),size);
	gtk_signal_connect(GTK_OBJECT(button7),"clicked",
							GTK_SIGNAL_FUNC(size_dialog_clicked_button),size);
	gtk_signal_connect(GTK_OBJECT(button8),"clicked",
								GTK_SIGNAL_FUNC(size_dialog_clicked_ok),size);
	gtk_signal_connect_object(GTK_OBJECT(button9),"clicked",
					GTK_SIGNAL_FUNC(gtk_widget_destroy),GTK_OBJECT(dialog));
	GTK_WIDGET_SET_FLAGS(button4,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button5,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button6,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button7,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button8,GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS(button9,GTK_CAN_DEFAULT);
	/* åܥ */
	if (size->def_width>0 && size->def_height>0) {
		check=gtk_check_button_new_with_label("");
		key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
													_("_Allow distortion"));
		gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),size->ratio);
	} else {
		check=NULL;
	}
	/* ԥܥ */
	spin0=gtk_spin_button_new(
		GTK_ADJUSTMENT(gtk_adjustment_new(size->width,1,G_MAXINT,1,5,0)),0,0);
	spin1=gtk_spin_button_new(
		GTK_ADJUSTMENT(gtk_adjustment_new(size->height,1,G_MAXINT,1,5,0)),0,0);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin0),TRUE);
	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin1),TRUE);
#ifndef USE_GTK2
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin0),GTK_SHADOW_IN);
	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin1),GTK_SHADOW_IN);
#endif
	gtk_signal_connect(GTK_OBJECT(spin0),"activate",
								GTK_SIGNAL_FUNC(size_dialog_activate),size);
	gtk_signal_connect(GTK_OBJECT(spin1),"activate",
								GTK_SIGNAL_FUNC(size_dialog_activate),size);
	gtk_signal_connect(GTK_OBJECT(spin0),"changed",
									GTK_SIGNAL_FUNC(size_dialog_changed),size);
	gtk_signal_connect(GTK_OBJECT(spin1),"changed",
									GTK_SIGNAL_FUNC(size_dialog_changed),size);
	/* ٥ */
	label0=gtk_label_new("");
	label1=gtk_label_new("");
	key=gtk_label_parse_uline(GTK_LABEL(label0),_("_Width"));
	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	key=gtk_label_parse_uline(GTK_LABEL(label1),_("_Height"));
	gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,GDK_MOD1_MASK,0);
	/* ơ֥ */
	if (button0!=NULL && button1!=NULL && button2!=NULL && button3!=NULL) {
		table=gtk_table_new(2,4,FALSE);
		gtk_table_attach_defaults(GTK_TABLE(table),button0,0,1,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button1,1,2,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button2,2,3,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button3,3,4,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button4,0,1,1,2);
		gtk_table_attach_defaults(GTK_TABLE(table),button5,1,2,1,2);
		gtk_table_attach_defaults(GTK_TABLE(table),button6,2,3,1,2);
		gtk_table_attach_defaults(GTK_TABLE(table),button7,3,4,1,2);
	} else {
		table=gtk_table_new(1,4,FALSE);
		gtk_table_attach_defaults(GTK_TABLE(table),button4,0,1,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button5,1,2,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button6,2,3,0,1);
		gtk_table_attach_defaults(GTK_TABLE(table),button7,3,4,0,1);
	}

	/* ե졼ȥܥå */
	vbox=gtk_vbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
	gtk_box_pack_start(GTK_BOX(vbox),table,FALSE,FALSE,0);

	hbox0=gtk_hbox_new(FALSE,8);
	gtk_container_set_border_width(GTK_CONTAINER(hbox0),8);
	hbox1=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),label0,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),spin0,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
	hbox1=gtk_hbox_new(FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),label1,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(hbox1),spin1,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(hbox0),hbox1,TRUE,TRUE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);

	if (check!=NULL)
		gtk_box_pack_start(GTK_BOX(vbox),check,FALSE,FALSE,0);

	hbox0=gtk_hbox_new(FALSE,8);
	gtk_box_pack_end(GTK_BOX(hbox0),button9,FALSE,FALSE,0);
	gtk_box_pack_end(GTK_BOX(hbox0),button8,FALSE,FALSE,0);
	gtk_box_pack_start(GTK_BOX(vbox),hbox0,FALSE,FALSE,0);
	gtk_container_add(GTK_CONTAINER(dialog),vbox);

	/* ɽ */
	gtk_widget_set_sensitive(button8,FALSE);
	gtk_widget_grab_focus(button9);

	edit=TRUE;
	def_view=-1;
	size_clicked_ok=FALSE;

	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
	gtk_grab_add(dialog);
	gtk_widget_show_all(dialog);
	gtk_main();

	return size_clicked_ok;
}
